@@ -1,7 +1,7 @@
 package App::lcpan::Cmd::weaver_authors_by_role_count;
 
-our $DATE = '2017-01-20'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2019-11-20'; # DATE
+our $VERSION = '0.030'; # VERSION
 
 use 5.010;
 use strict;
@@ -59,7 +59,7 @@ App::lcpan::Cmd::weaver_authors_by_role_count - List authors ranked by number of
 
 =head1 VERSION
 
-This document describes version 0.02 of App::lcpan::Cmd::weaver_authors_by_role_count (from Perl distribution App-lcpan-CmdBundle-weaver), released on 2017-01-20.
+This document describes version 0.030 of App::lcpan::Cmd::weaver_authors_by_role_count (from Perl distribution App-lcpan-CmdBundle-weaver), released on 2019-11-20.
 
 =head1 DESCRIPTION
 
@@ -68,7 +68,11 @@ This module handles the L<lcpan> subcommand C<weaver-authors-by-role-count>.
 =head1 FUNCTIONS
 
 
-=head2 handle_cmd(%args) -> [status, msg, result, meta]
+=head2 handle_cmd
+
+Usage:
+
+ handle_cmd(%args) -> [status, msg, payload, meta]
 
 List authors ranked by number of Pod::Weaver roles.
 
@@ -88,6 +92,18 @@ Defaults to C<~/cpan>.
 
 Filename of index.
 
+If C<index_name> is a filename without any path, e.g. C<index.db> then index will
+be located in the top-level of C<cpan>. If C<index_name> contains a path, e.g.
+C<./index.db> or C</home/ujang/lcpan.db> then the index will be located solely
+using the C<index_name>.
+
+=item * B<use_bootstrap> => I<bool> (default: 1)
+
+Whether to use bootstrap database from App-lcpan-Bootstrap.
+
+If you are indexing your private CPAN-like repository, you want to turn this
+off.
+
 =back
 
 Returns an enveloped result (an array).
@@ -95,7 +111,7 @@ Returns an enveloped result (an array).
 First element (status) is an integer containing HTTP status code
 (200 means OK, 4xx caller error, 5xx function error). Second element
 (msg) is a string containing error message, or 'OK' if status is
-200. Third element (result) is optional, the actual result. Fourth
+200. Third element (payload) is optional, the actual result. Fourth
 element (meta) is called result metadata and is optional, a hash
 that contains extra information.
 
@@ -123,7 +139,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2017 by perlancar@cpan.org.
+This software is copyright (c) 2019, 2017, 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
